clear all

loc path_inf "${WorkFolder_version}"
loc path_table "${path_table}"

use "`path_table'\Base_16_26_${title}.dta", clear
by case: gen ng26=ngnp_fm_sr/ngnp_fm_sr[_n-1]-1
by case: gen rg26=rgnp_fm_sr/rgnp_fm_sr[_n-1]-1
gen aux=debt3 if year ==2016
by case: egen D16=mean(aux)
drop aux
gen NDo16=D16
keep if year ==2026
keep case year mYG ERG mYT gb R debt3 ngnp_fm_sr rgnp_fm_sr nps_gov beta beta_fp rg26 ng26 cum_inf NDo16
loc inf=1.6/100
gen cum_inf26=cum_inf if year==2026
loc horizon =36
forvalues t=27/`horizon' {
	loc t_1=`t'-1
	gen inf`t'=`inf'
	gen cum_inf`t'=cum_inf`t_1'*(1+inf`t')
}

gen rgb_lp=(1+gb)/(1+`inf')-1

gen mYS=mYG

gen NGNP26=ngnp_fm_sr if year ==2026
gen RGNP26=NGNP26/cum_inf26 if year ==2026
gen S26=nps_gov if year ==2026
gen RS26=S26/cum_inf26 if year ==2026
gen s26=S26/NGNP26
gen RD26_proy=debt3/cum_inf26 if year ==2026
gen D26_proy=debt3 if year ==2026

tempfile presimu
save `presimu', replace

loc Tnsupsost=6
loc Tnrho=3

qui forvalues nss =0/`Tnsupsost' {
	drop _all
	use `presimu'
	loc ss_`nss'=0.01+(`nss'-1)/200
	if `nss'==0 loc ss_`nss'=.
	if `nss'==0 loc tss`nss'="NDR"
	if `nss'==1 loc tss`nss'="s2026"
	if `nss'>=2 & `nss'<=6 loc tss`nss'=subinstr("`ss_`nss''",".","",.) 
	gen ss=`ss_`nss''

	loc d_sost`nss'=`ss_`nss''* ( (1+gb) / (R-gb) )
	gen d_sost`nss'=`d_sost`nss''
	if `nss'==0 replace d_sost`nss'=debt3/NGNP26 if year==2026

	gen D26=d_sost`nss'*NGNP26
	gen RD26=D26/cum_inf26 if year ==2026
	gen NQ26=NDo16-D26
	gen nq26nd16=NQ26/NDo16
	gen nq26nd26=nq26nd16

	replace nq26nd16 =0 if nq26nd16<0
	replace nq26nd26 =0 if nq26nd26<0
	replace NQ26 =0 if nq26nd26==0

	gen d26=D26/NGNP26 
	loc tol=0.001 
	tempfile presimu_`tss`nss''
	save `presimu_`tss`nss''', replace
	forvalues nrho =1/`Tnrho' {
		loc rho=0.8+(`nrho'-1)/10
		loc trho=subinstr("`rho'",".","0",.) 
		drop _all
		use `presimu_`tss`nss'''
		loc t=27
		loc maxdif=1
		while (`t'<=`horizon') {
			loc t_1=`t'-1
			gen s`t' =d`t_1' * ((R-gb)/(1+gb)) 
			gen a`t'=s`t'-s`t_1' 
			replace a`t'=0 if a`t'<=`tol'
			replace s`t'=s`t_1' if a`t'<=`tol'
			gen rgb`t'=(1-`rho')*rg`t_1'+`rho'*rgb_lp
			gen rg`t'=rgb`t' -mYS*a`t'
			gen RGNP`t'=RGNP`t_1'*(1+rg`t')
			gen NGNP`t'=RGNP`t'*cum_inf`t'
			gen S`t'=s`t'*NGNP`t'
			gen RS`t'=s`t'*RGNP`t'
			gen A`t'=S`t'-S`t_1' 
			gen RA`t'=RS`t'-RS`t_1' 
			gen D`t'=D`t_1'*(1+R)-S`t'
			gen RD`t'=D`t'/cum_inf`t'
			gen d`t'=D`t'/NGNP`t'
			sum a`t'
			loc maxdif=r(max)
			loc ++t
		}
		drop year ngnp_fm_sr beta nps_gov debt3 beta_fp rgnp_fm_sr cum_inf 
		reshape long s a ngb ng NGNP RGNP D S RD RS RA d A rg rgb inf cum_inf, i(case) j(year)
		replace year=year+2000
		duplicates report case year 
		sort case year 
		by case: egen SUM_RGNP=sum(RGNP)
		replace SUM_RGNP =. if year !=2036
		gen RGNP_rgb=RGNP if year ==2026
		forvalues t=2027/2036 {
			by case: replace RGNP_rgb=RGNP_rgb[_n-1] * (1+rgb) if year==`t'
		}
		by case: egen SUM_RGNP_rgb=sum(RGNP_rgb)
		replace SUM_RGNP_rgb=. if year !=2036
		gen rlost=SUM_RGNP_rgb-SUM_RGNP
		replace rlost =0 if rlost <=0 
		gen rho=`rho'

		loc nsheet_`nss'_`nrho' "rho_`trho'_ss_`tss`nss''"
		save "`path_table'\\${title}_`nsheet_`nss'_`nrho''.dta", replace
		loc aux=`ss_`nss''*100 
		loc index_`nss'_`nrho' "Exercise under rho = `rho' and Debt Stabilizing Primary Fiscal Surplus = `aux' %"
		if `nss'==0 loc index_`nss'_`nrho' "Exercise with No Debt Relief (NDR), under rho = `rho'" 
		if `nss'==1 loc index_`nss'_`nrho' "Exercise under rho = `rho' and Debt Stabilizing Primary Fiscal Surplus = s2026"
	}
}

use "`path_table'\Base_16_26_${title}.dta", clear
gen J=-1
gen base=1
gen rho=.
loc nbase=2
qui forvalues nss =0/`Tnsupsost' {
	forvalues nrho =1/`Tnrho' {
		append using "`path_table'\\${title}_`nsheet_`nss'_`nrho''.dta"
		replace base =`nbase' if base ==.
		replace J = `nss' if base ==`nbase' 
		loc ++nbase
	}
}

duplicates report J rho case year 
duplicates report base case year 
sort base case year 
save "`path_table'\Base_16_26_36_${title}.dta", replace

preserve
drop _all
loc sheets=(`Tnsupsost'+1)*`Tnrho'
set obs `sheets'
gen Sheet = ""
gen Description =""
loc row=1
qui forvalues nss =0/`Tnsupsost' {
	forvalues nrho =1/`Tnrho' {
		replace Sheet ="`nsheet_`nss'_`nrho''" if _n==`row'
		replace Description ="`index_`nss'_`nrho''" if _n==`row'
		loc ++row
	}
}
export excel using "`path_inf'\${title}_report.xlsx" , sheet("index") cell(c3) sheetreplace  firstrow(variables)
restore

use "`path_table'\\${title}_`nsheet_1_1'.dta"
d, replace clear 
replace varlab=subinstr(varlab,"Debt Stabilizing s = s2026","by Debt Stabilizing Primary Fiscal Surplus",.)
keep name varlab
export excel using "`path_inf'\${title}_report.xlsx" , sheet("labels") cell(b1) sheetreplace  firstrow(variables)

qui forvalues nss =0/`Tnsupsost' {
	forvalues nrho =1/`Tnrho' {
		drop _all
		use "`path_table'\\${title}_`nsheet_`nss'_`nrho''.dta"
		noi di "rho = `rho', Debt Stabilizing s  =`ss_`nss'' , sheet: `nsheet_`nss'_`nrho''"
		noi sum nq26nd16
		export excel using "`path_inf'\${title}_report.xlsx" , sheet("`nsheet_`nss'_`nrho''") cell(a1) sheetreplace  firstrow(variables)
	}
}
*/


