
loc path_inf "${WorkFolder_version}"
loc path_figures "${path_figures}"
loc path_table "${path_table}"


use "`path_table'\Base_16_26_36_${title}.dta", clear

loc thickness="thick"

loc Tnsupsost=6
loc Tnrho=3

sort base year case 
duplicates report base J rho year
duplicates drop base J rho year, force

duplicates report base case year 
sort base case year 
gen RGNP_gov=.
replace RGNP_gov=rgnp_bm if year ==2016 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1+dp_rgdp_bm) if year ==2017 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1-3.89754/100) if year ==2018 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1-3.3138799/100) if year ==2019 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1-1.44451516059/100) if year ==2020 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1-1.47259109233/100) if year ==2021 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1-0.98773113341/100) if year ==2022 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1-0.48773113341/100) if year ==2023 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1+0.01226886659/100) if year ==2024 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1+0.51226886659/100) if year ==2025 & J==-1
replace RGNP_gov=RGNP_gov[_n-1]*(1+1.01226886659/100) if year ==2026 & J==-1

gen NGNP_gov=RGNP_gov*cum_inf

foreach var of varlist RGNP* NGNP* {
	replace `var'= `var'/1000
}

loc list_gnp "RGNP NGNP" 
loc titRGNP "Real GNP"
loc titNGNP  "Nominal GNP"
loc rnom "30 (5) 90"

/*
foreach rn of local list_gnp {
		twoway ///
			(	///
				line `rn'_gov year if J==-1, legend(on label(1 "Fiscal Plan projections"))		///
				lwidth(med`thickness' )  lcolor(maroon) ///
			) /// 
			, title("`tit`rn''") ytitle("Billions of dollars") legend( symxsize(*.5)  rows(1) ) ylabel(`rnom', grid)
		graph export  "`path_figures'\png\\Fiscal_plan_`rn'_1626.png", replace
		graph export  "`path_figures'\wmf\\Fiscal_plan_`rn'_1626.wmf", replace
}	
*/



use "`path_table'\Base_16_26_36_${title}.dta", clear

gen Pnq26nd16 =nq26nd16 *100

if "${odebt}"=="up" loc ytit "FV Reduction as % of total bonds and private loans"
if "${odebt}"=="low" loc ytit "FV Reduction as % of Debt included in Fiscal Plan"

if "${odebt}"=="up" loc stit "(total bonds and private loans)"
if "${odebt}"=="low" loc stit "(Debt included in Fiscal Plan)"

scatter Pnq26nd16 ss if J>0 & rho==1 & year ==2026 , title("Necessary Face Value Reduction") subtitle("`stit'") ytitle( "`ytit'") msize(small) xtitle("s (Debt Stabilizing Primary Fiscal Surplus)")
graph play  "${WorkFolder_version}\04_extra_editgraph.grec"
graph export  "`path_figures'\png\\${title}_scatter_s_Pnq26nd16.png", replace
graph export  "`path_figures'\wmf\\${title}_scatter_s_Pnq26nd16.wmf", replace
graph close


gen BNQ2017=NQ26/1000
scatter BNQ2017 ss if J>0 & rho==1 & year ==2026 , title("Necessary Face Value Reduction") subtitle("`stit'")  ytitle("Billions of $") msize(small) xtitle("s (Debt Stabilizing Primary Fiscal Surplus)")
graph play  "${WorkFolder_version}\04_extra_editgraph.grec"
graph export  "`path_figures'\png\\${title}_scatter_s_NQUSD2017.png", replace
graph export  "`path_figures'\wmf\\${title}_scatter_s_NQUSD2017.wmf", replace

graph close

if "${odebt}"=="up" {
	gen Pd26 =d *100 

	loc ytit "Sustainable Debt, % of GNP"

	gen D2017B=D/1000 
	scatter D2017B ss if J>0 & rho==1 & year ==2026 , title("Sustainable Debt")  ytitle("Billions of $") msize(small) xtitle("s (Debt Stabilizing Primary Fiscal Surplus)")
	graph play  "${WorkFolder_version}\04_extra_editgraph.grec"
	graph export  "`path_figures'\png\\${title}_scatter_s_D2017B.png", replace
	graph export  "`path_figures'\wmf\\${title}_scatter_s_D2017B.wmf", replace
	graph close

	mat statnq=J(6,9,.)
	forvalues j=1/6 {
		mat statnq[`j',1]=`j'
		sum ss   if J==`j' & year ==2026 & rho==1, mean
		mat statnq[`j',2]=r(mean)
		sum case if J==`j' & year ==2026 & rho==1, mean
		mat statnq[`j',3]=r(N)
		sum rho  if J==`j' & year ==2026 & case==1, mean
		mat statnq[`j',4]=r(N)

		sum D2017B if J==`j' & year ==2026 
		mat statnq[`j',5]=r(N)
		mat statnq[`j',6]=r(min)
		mat statnq[`j',7]=r(max)
		sum D2017B  if J==`j' & case ==4 & year ==2026 
		mat statnq[`j',8]=r(mean)
	}
	preserve
	drop _all
	svmat statnq
	export excel using "`path_inf'\Stats_D2017B.xlsx" , sheet("${title}") cell(a18) sheetmodify firstrow(variables)
	restore
}
preserve
duplicates report case year J rho
sum d_3 if year==2016 & J==-1 & case==1
loc d_gnp_2016=r(mean)
keep if J==0
keep if year ==2026
keep if rho==1
duplicates  report case
sum d if case ==4
loc d_gnp_2026=r(mean)
drop if case ==4
keep case d
gen aux=1
gen d_gnp_2016=`d_gnp_2016'
gen d_gnp_2026=`d_gnp_2026'
order case d aux d_gnp_2016 d_gnp_2026
export excel using "`path_inf'\Figure3.xlsx" , sheet("${title}") cell(a2) sheetmodify firstrow(variables)
restore

preserve
duplicates report case year J rho
sum s if J==0 & rho ==1 & year ==2036
mat s_nohaircut=J(1,4,.)
mat s_nohaircut[1,1]=r(N)
mat s_nohaircut[1,2]=r(mean)
mat s_nohaircut[1,3]=r(min)
mat s_nohaircut[1,4]=r(max)
clear 
svmat s_nohaircut
gen title ="${title}"
order title s_nohaircut*
loc nn = $count+20
export excel using "`path_inf'\s_nohaircut.xlsx", sheet("s_nohaircut") cell(a`nn') sheetmodify 


.